@@ -23,7 +23,7 @@ function(y, x, L, delta, sigma, beta.mle = NULL){
   W.est<-diag(c(w*(w-2)-2*sigma*w1+sigma*tau1*(w1+2*sigma*w2)))
   Z2<-Z*Z
   W.est.est<-diag(c(Z%*%(W+2*sigma*W1)%*%Zd%*%one))
-  Delta.1<--(1/sigma^4)*t(x)%*%W.est%*%Zd%*%x
+  Delta.1<-(1/sigma^4)*t(x)%*%W.est%*%Zd%*%x
   Delta.2<--(1/sigma^6)*t(x)%*%(W%*%Z2%*%W-2*sigma*W%*%Z2%*%W1-6*sigma^2*W1%*%Z2%*%W1)%*%x
   Delta.3<-(1/sigma^5)*t(x)%*%W1%*%W.est.est%*%x
   Delta<--0.5*Delta.1+0.25*Delta.2+0.5*tau2*Delta.3
